==> kpopup-0.7.0.tar.gz: kpopup-0.7.0/kpopup/make_popup.h <==
/***************************************************************************
                          make_popup.h  -  description
                          ----------------------------
    copyright            : (C) 2000 by Torsten Henschel
    email                : henschel@fh-brandenburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MAKE_KOPUP_H
#define MAKE_KOPUP_H

#include <kapp.h>
#include <kdialog.h>

#include <qcombobox.h>
#include <qlabel.h>
#include <qmultilinedit.h>
#include <qpushbutton.h>

class make_Popup : public KDialog
{
 Q_OBJECT

 public:
        make_Popup(QWidget *parent, const char *name);
        ~make_Popup();
        void ReadBrowseList();
        void ReadHostName();

        QComboBox *CB_Receiver;
        QLabel *L_Receiver;
        QLabel *L_Text;
        QMultiLineEdit *MLE_Text;
        QPushButton *B_Cancel;
        QPushButton *B_Ok;

 public slots:
              void SendPopup();

 private:
         char *hostname;
};

#endif

==> kpopup-0.9.1.tar.gz: kpopup-0.9.1/kpopup/make_popup.h <==
/***************************************************************************
                          make_popup.h  -  description
                          ----------------------------
    copyright            : (C) 2000 by Torsten Henschel
    email                : thenschel@henschelsoft.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MAKE_KOPUP_H
#define MAKE_KOPUP_H

#include <kapp.h>
#include <kdialog.h>

#include <qcombobox.h>
#include <qlabel.h>
#include <qmultilinedit.h>
#include <qpushbutton.h>

class Make_Popup : public KDialog {
    Q_OBJECT

    public:
        Make_Popup(QWidget *parent, const char *name);
        ~Make_Popup();
        void readBrowseList();
        void readHostName();

        QComboBox *cb_Receiver;
        QLabel *lbl_Receiver;
        QLabel *lbl_Text;
        QMultiLineEdit *mle_Text;
        QPushButton *btn_Cancel;
        QPushButton *btn_Ok;

     public slots:
        void sendPopup();

     private:
        char *hostname;
};

#endif
